Module base

Module base 

The base module contains the core functionality of the Shulkerscript language.

Modules

log
Module containing structures and implementations for logging messages to the user.
source_file
Module for handling source files and their elements.

Structs

FileProviderError
The error type for FileProvider operations.
FsProvider
Provides file contents from the file system.
PrintHandler
A simple error handler that prints the error to the standard error stream.
SilentHandler
A handler that does not print the error to the standard error stream.
VoidHandler
Is a struct that implements Handler trait by doing nothing with the errors and never signifying that it has received a message.

Enums

Error
An error that occurred during compilation.

Traits

FileProvider
A trait for providing file contents.
Handler
Represents a trait responsible for handling diagnostics in the interpreter.

Type Aliases

Result
A specialized Result type for this crate.