The base module contains the core functionality of the Shulkerscript language.
Modules
- log
- Module containing structures and implementations for logging messages to the user.
- source_
file - Module for handling source files and their elements.
Structs
- File
Provider Error - The error type for
FileProvideroperations. - FsProvider
- Provides file contents from the file system.
- Print
Handler - A simple error handler that prints the error to the standard error stream.
- Silent
Handler - A handler that does not print the error to the standard error stream.
- Void
Handler - Is a struct that implements
Handlertrait by doing nothing with the errors and never signifying that it has received a message.
Enums
- Error
- An error that occurred during compilation.
Traits
- File
Provider - A trait for providing file contents.
- Handler
- Represents a trait responsible for handling diagnostics in the interpreter.